@@ -15,6 +15,7 @@ import os
 import types
 from collections import OrderedDict, Counter
 import importlib
+import inspect
 from typing import Dict, Any
 
 from fontbakery.callable import (
@@ -69,14 +70,17 @@ class CheckRunner:
         # TODO: transform all iterables that are list like to tuples
         # to make sure that they won't change anymore.
         # Also remove duplicates from list like iterables
-        self.config = config
+
+        # Add the profile's config values "underneath" the user's config
+        self.config = profile.merge_default_config(config)
         self._custom_order = config["custom_order"]
         self._explicit_checks = config["explicit_checks"]
         self._exclude_checks = config["exclude_checks"]
         self._iterargs = OrderedDict()
         for singular, plural in profile.iterargs.items():
-            values[plural] = tuple(values[plural])
-            self._iterargs[singular] = len(values[plural])
+            if plural in values:
+                values[plural] = tuple(values[plural])
+                self._iterargs[singular] = len(values[plural])
 
         if not values_can_override_profile_names:
             for name in values:
@@ -171,6 +175,12 @@ class CheckRunner:
             we can connect the check result with more in depth
             knowledge from the check definition.
         """
+        if check.configs:
+            new_globals = {
+                varname: self.config.get(check.id, {}).get(varname)
+                for varname in check.configs
+            }
+            check.inject_globals(new_globals)
         try:
             # A check can be either a normal function that returns one Status or a
             # generator that yields one or more. The latter will return a generator
@@ -181,13 +191,13 @@ class CheckRunner:
                 # Iterate over sub-results one-by-one, list(result) would abort on
                 # encountering the first exception.
                 for sub_result in result:  # Might raise.
-                    yield self._check_result(sub_result)
+                    yield self._override_status(self._check_result(sub_result), check)
                 return  # Do not fall through to rest of method.
         except Exception as e:
             error = FailedCheckError(e)
             result = (ERROR, error)
 
-        yield self._check_result(result)
+        yield self._override_status(self._check_result(result), check)
 
     def _evaluate_condition(self, name, iterargs, path=None):
         if path is None:
@@ -391,7 +401,16 @@ class CheckRunner:
             return (status, None)
 
         try:
-            return None, self._get_args(check, iterargs)
+            args = self._get_args(check, iterargs)
+            # Run the generators now, so we can test if they're empty
+            for k,v in args.items():
+                if inspect.isgenerator(v) or inspect.isgeneratorfunction(v):
+                    args[k] = list(v)
+
+            if all(not x for x in args.values()):
+                status = (SKIP, "No applicable arguments")
+                return (status, None)
+            return None, args
         except Exception as error:
             status = (ERROR, FailedDependenciesError(check, error))
             return (status, None)
@@ -505,6 +524,19 @@ class CheckRunner:
         for result in drive_session_protocol(session_gen, next_check_gen):
             receive_result_fn(result)
 
+    def _override_status(self, result, check):
+        # Potentially override the status based on the config file.
+        # Replaces the status with config["overrides"][check.id][message.code]
+        status, message = result
+        status_overrides = self.config.get("overrides", {}).get(check.id)
+        if (
+            not status_overrides
+            or not isinstance(message, Message)
+            or message.code not in status_overrides
+        ):
+            return result
+        return Status(status_overrides[message.code]), message
+
 
 def drive_session_protocol(session_gen, next_check_gen):
     # can't send anything but None on first iteration
