@@ -17,6 +17,7 @@
 from fontbakery.checkrunner import CheckRunner
 from fontbakery.configuration import Configuration
 from fontbakery.profile import Profile, get_module_profile
+import defcon
 
 
 class CheckTester:
@@ -85,22 +86,54 @@ class CheckTester:
 
     def __call__(self, values, condition_overrides={}):
         from fontTools.ttLib import TTFont
+        from fontbakery.profiles.googlefonts_conditions import family_metadata
+        from glyphsLib import GSFont
+        import os
+
         if isinstance(values, str):
-            values = {'font': values,
-                      'fonts': [values]}
+            if values.endswith('README.md'):
+                values = {'readme_md': values}
+            elif values.endswith('.ufo'):
+                values = {'ufo': values}
+            elif values.endswith('.designspace'):
+                values = {'designspace': values}
+            elif values.endswith('METADATA.pb'):
+                fonts = [os.path.join(os.path.dirname(values), f.filename)
+                         for f in family_metadata(values).fonts]
+                values = {'metadata_pb': values,
+                          'font': fonts[0], #FIXME!
+                          'fonts': fonts}
+            else:
+                values = {'font': values,
+                          'fonts': [values]}
         elif isinstance(values, TTFont):
             values = {'font': values.reader.file.name,
                       'fonts': [values.reader.file.name],
                       'ttFont': values,
                       'ttFonts': [values]}
+        elif isinstance(values, GSFont):
+            values = {'glyphs_file': values.filepath,
+                      'glyphs_files': [values.filepath],
+                      'glyphsFile': values,
+                      'glyphsFiles': [values]}
+        elif isinstance(values, defcon.Font):
+            values = {'ufo_font': values}
         elif isinstance(values, list):
-            if isinstance(values[0], str):
-                values = {'fonts': values}
-            elif isinstance(values[0], TTFont):
-                values = {'fonts': [v.reader.file.name for v in values],
-                          'ttFonts': values}
+            if values:
+                if isinstance(values[0], str):
+                    values = {'fonts': values}
+                elif isinstance(values[0], TTFont):
+                    values = {'fonts': [v.reader.file.name for v in values],
+                              'ttFonts': values}
+                elif isinstance(values[0], GSFont):
+                    values = {'glyphs_files': [v.filepath for v in values],
+                              'glyphsFiles': values}
+            else:
+                values = {}
 
-        self.runner = CheckRunner(self.profile, values, Configuration(explicit_checks=[self.check_id]))
+        self.runner = CheckRunner(self.profile,
+                                  values,
+                                  Configuration(explicit_checks=[self.check_id], full_lists=True))
         for check_identity in self.runner.order:
             _, check, _ = check_identity
             if check.id != self.check_id:
@@ -124,12 +157,22 @@ def TEST_FILE(f):
     return portable_path("data/test/" + f)
 
 
-def assert_PASS(check_results, reason="with a good font..."):
-    from fontbakery.checkrunner import PASS
+def GLYPHSAPP_TEST_FILE(f):
+    import glyphsLib
+    the_file = portable_path("data/test/glyphs_files/" + f)
+    return glyphsLib.load(open(the_file))
+
+
+def assert_PASS(check_results, reason="with a good font...", ignore_error=None):
+    from fontbakery.checkrunner import PASS, ERROR
     print(f"Test PASS {reason}")
     status, message = list(check_results)[-1]
-    assert status == PASS
-    return str(message)
+    if ignore_error and status == ERROR:
+        print(ignore_error)
+        return None
+    else:
+        assert status == PASS
+        return str(message)
 
 
 def assert_SKIP(check_results, reason=""):
@@ -140,14 +183,18 @@ def assert_SKIP(check_results, reason=""):
     return str(message)
 
 
-def assert_results_contain(check_results, expected_status, expected_msgcode=None, reason=None):
+def assert_results_contain(check_results,
+                           expected_status,
+                           expected_msgcode=None,
+                           reason=None,
+                           ignore_error=None):
     """
     This helper function is useful when we want to make sure that
     a certain log message is emited by a check but it can be in any
     order among other log messages.
     """
     from fontbakery.message import Message
-    from fontbakery.checkrunner import PASS, DEBUG
+    from fontbakery.checkrunner import PASS, DEBUG, ERROR
     if not reason:
         reason = f"[{expected_msgcode}]"
     if not expected_msgcode:
@@ -155,6 +202,12 @@ def assert_results_contain(check_results, expected_status, expected_msgcode=None
 
     print(f"Test {expected_status} {reason}")
     check_results = list(check_results)
+
+    for status, _ in check_results:
+        if ignore_error and status == ERROR:
+            print(ignore_error)
+            return None
+
     for status, msg in check_results:
         if status not in [PASS, DEBUG] and not isinstance(msg, Message):
             raise Exception(f"Bare Python strings no longer supported in result values.\n"
