@@ -16,6 +16,7 @@ from fontbakery.callable import (
     FontBakeryCondition,
     FontBakeryExpectedValue,
 )
+from fontbakery.configuration import Configuration
 from fontbakery.message import Message
 from fontbakery.section import Section
 from fontbakery.utils import is_negated
@@ -61,6 +62,13 @@ def get_module_profile(module, name=None):
 
 
 class Profile:
+    """
+    Profiles may specify default configuration values (used to parameterize
+    checks), which are then overridden by values in the user's configuration
+    file.
+    """
+    configuration_defaults = {}
+
     def __init__(
         self,
         sections=None,
@@ -1052,8 +1060,21 @@ class Profile:
                 result.append(check)
         return result
 
+    def merge_default_config(self, user_config):
+        """
+        Forms a configuration object based on defaults provided by the profile,
+        overridden by values in the user's configuration file.
+        """
+        copy = Configuration(**self.configuration_defaults)
+        copy.update(user_config)
+        return copy
+
 
 def _check_log_override(overrides, status, message):
+    # These constants are merely meant to be used
+    # so that the check_override declarations are more readable:
+    from fontbakery.message import (KEEP_ORIGINAL_STATUS,
+                                    KEEP_ORIGINAL_MESSAGE)
     result_status = status
     result_message = message
     override = False
@@ -1065,9 +1086,9 @@ def _check_log_override(overrides, status, message):
         ):
             continue
         override = True
-        if new_status is not None:
+        if new_status is not KEEP_ORIGINAL_STATUS:
             result_status = new_status
-        if new_message_string is not None:
+        if new_message_string is not KEEP_ORIGINAL_MESSAGE:
             # If it looks like an instance of Message we reuse the code,
             # as it is the same condition this makes totally sense.
             result_message = Message(result_message.code, new_message_string)
