@@ -4,11 +4,14 @@ Checks for Adobe Fonts (formerly known as Typekit).
 import unicodedata
 
 from fontbakery.callable import check
-from fontbakery.status import PASS, FAIL, WARN
-from fontbakery.section import Section
 from fontbakery.fonts_profile import profile_factory
+from fontbakery.message import (Message,
+                                KEEP_ORIGINAL_MESSAGE)
 from fontbakery.profiles.universal import UNIVERSAL_PROFILE_CHECKS
-from fontbakery.message import Message
+from fontbakery.section import Section
+from fontbakery.status import PASS, FAIL, WARN
+from fontbakery.utils import add_check_overrides
+
 
 profile_imports = ('fontbakery.profiles.universal',)
 profile = profile_factory(default_section=Section("Adobe Fonts"))
@@ -20,21 +23,17 @@ ADOBEFONTS_PROFILE_CHECKS = \
     ]
 
 OVERRIDDEN_CHECKS = [
-    'com.google.fonts/check/dsig',
     'com.google.fonts/check/whitespace_glyphs',
     'com.google.fonts/check/valid_glyphnames',
 ]
-ADOBEFONTS_PROFILE_CHECKS += [f'{cid}:{profile.profile_tag}' for cid in OVERRIDDEN_CHECKS]
-
-ADOBEFONTS_PROFILE_CHECKS[:] = [cid for cid in ADOBEFONTS_PROFILE_CHECKS
-                                            if cid not in OVERRIDDEN_CHECKS]
 
 
 @check(
     id = 'com.adobe.fonts/check/family/consistent_upm',
     rationale = """
         While not required by the OpenType spec, we (Adobe) expect that a group of fonts designed & produced as a family have consistent units per em.
-    """
+    """,
+    proposal = 'https://github.com/googlefonts/fontbakery/pull/2372'
 )
 def com_adobe_fonts_check_family_consistent_upm(ttFonts):
     """Fonts have consistent Units Per Em?"""
@@ -82,7 +81,8 @@ def _quick_and_dirty_glyph_is_empty(font, glyph_name):
         Font language, script, and character set tagging approaches typically have an underlying assumption that letters (i.e. characters with Unicode general category 'Ll', 'Lm', 'Lo', 'Lt', or 'Lu', which includes CJK ideographs and Hangul syllables) with entries in the 'cmap' table have glyphs with ink (with a few exceptions, notably the Hangul "filler" characters).
 
         This check is intended to identify fonts in which such letters have been mapped to empty glyphs (typically done as a form of subsetting). Letters with empty glyphs should have their entries removed from the 'cmap' table, even if the empty glyphs are left in place (e.g. for CID consistency).
-    """
+    """,
+    proposal = 'https://github.com/googlefonts/fontbakery/pull/2460'
 )
 def com_adobe_fonts_check_find_empty_letters(ttFont):
     """Letters in font have glyphs that are not empty?"""
@@ -110,32 +110,32 @@ def com_adobe_fonts_check_find_empty_letters(ttFont):
         yield PASS, "No empty glyphs for letters found."
 
 
-# ToDo: add many more checks...
-
 profile.auto_register(globals())
 
-com_google_fonts_check_dsig_adobefonts = profile.check_log_override(
-    'com.google.fonts/check/dsig'
-  , reason='For Adobe this issue is not as severe '\
-            + 'as assessed in the original check.'
-  , overrides = (
-        (   'lacks-signature' # override_target -> a specific Message.code (string)
-          , WARN # new_status -> None: keep old status
-          , None # new_message_string -> None: keep old message
-          )
+
+profile.check_log_override(
+    # from `universal` profile:
+    'com.google.fonts/check/whitespace_glyphs',
+    reason = 'For Adobe, this is not as severe ' \
+           + 'as assessed in the original check for 0x00A0.',
+    overrides = (
+        ('missing-whitespace-glyph-0x00A0', WARN, KEEP_ORIGINAL_MESSAGE)
     ,)
 )
 
-com_google_fonts_check_whitespace_glyph_nbsp = profile.check_log_override(
-    'com.google.fonts/check/whitespace_glyphs',
-    reason='For Adobe, this is not as severe '\
-           + 'as assessed in the original check for 0x00A0.',
-    overrides = (('missing-whitespace-glyph-0x00A0', WARN, None),)
+
+profile.check_log_override(
+    # from `universal` profile:
+    'com.google.fonts/check/valid_glyphnames',
+    overrides = (
+        ('found-invalid-names', WARN, KEEP_ORIGINAL_MESSAGE)
+    ,)
 )
 
-com_google_fonts_check_valid_glyphnames_adobefonts = profile.check_log_override(
-    'com.google.fonts/check/valid_glyphnames'
-  , overrides = (('found-invalid-names', WARN, None),)
-)
+
+ADOBEFONTS_PROFILE_CHECKS = \
+    add_check_overrides(ADOBEFONTS_PROFILE_CHECKS,
+                        profile.profile_tag,
+                        OVERRIDDEN_CHECKS)
 
 profile.test_expected_checks(ADOBEFONTS_PROFILE_CHECKS, exclusive=True)
