@@ -19,9 +19,7 @@ profile_imports = [
     """,
     conditions = ['is_variable_font',
                   'regular_wght_coord'],
-    misc_metadata = {
-        'request': 'https://github.com/googlefonts/fontbakery/issues/1707'
-    }
+    proposal = 'https://github.com/googlefonts/fontbakery/issues/1707'
 )
 def com_google_fonts_check_varfont_regular_wght_coord(ttFont, regular_wght_coord):
     """The variable font 'wght' (Weight) axis coordinate must be 400 on the
@@ -46,9 +44,7 @@ def com_google_fonts_check_varfont_regular_wght_coord(ttFont, regular_wght_coord
     """,
     conditions = ['is_variable_font',
                   'regular_wdth_coord'],
-    misc_metadata = {
-        'request': 'https://github.com/googlefonts/fontbakery/issues/1707'
-    }
+    proposal = 'https://github.com/googlefonts/fontbakery/issues/1707'
 )
 def com_google_fonts_check_varfont_regular_wdth_coord(ttFont, regular_wdth_coord):
     """The variable font 'wdth' (Width) axis coordinate must be 100 on the 'Regular' instance."""
@@ -72,9 +68,7 @@ def com_google_fonts_check_varfont_regular_wdth_coord(ttFont, regular_wdth_coord
     """,
     conditions = ['is_variable_font',
                   'regular_slnt_coord'],
-    misc_metadata = {
-        'request': 'https://github.com/googlefonts/fontbakery/issues/1707'
-    }
+    proposal = 'https://github.com/googlefonts/fontbakery/issues/1707'
 )
 def com_google_fonts_check_varfont_regular_slnt_coord(ttFont, regular_slnt_coord):
     """The variable font 'slnt' (Slant) axis coordinate must be zero on the 'Regular' instance."""
@@ -98,9 +92,7 @@ def com_google_fonts_check_varfont_regular_slnt_coord(ttFont, regular_slnt_coord
     """,
     conditions = ['is_variable_font',
                   'regular_ital_coord'],
-    misc_metadata = {
-        'request': 'https://github.com/googlefonts/fontbakery/issues/1707'
-    }
+    proposal = 'https://github.com/googlefonts/fontbakery/issues/1707'
 )
 def com_google_fonts_check_varfont_regular_ital_coord(ttFont, regular_ital_coord):
     """The variable font 'ital' (Italic) axis coordinate must be zero on the 'Regular' instance."""
@@ -120,25 +112,23 @@ def com_google_fonts_check_varfont_regular_ital_coord(ttFont, regular_ital_coord
     rationale = """
         According to the Open-Type spec's registered design-variation tag 'opsz' available at https://docs.microsoft.com/en-gb/typography/opentype/spec/dvaraxistag_opsz
 
-        If a variable font has a 'opsz' (Optical Size) axis, then the coordinate of its 'Regular' instance is recommended to be a value in the range 9 to 13.
+        If a variable font has an 'opsz' (Optical Size) axis, then the coordinate of its 'Regular' instance is recommended to be a value in the range 10 to 16.
     """,
     conditions = ['is_variable_font',
                   'regular_opsz_coord'],
-    misc_metadata = {
-        'request': 'https://github.com/googlefonts/fontbakery/issues/1707'
-    }
+    proposal = 'https://github.com/googlefonts/fontbakery/issues/1707'
 )
 def com_google_fonts_check_varfont_regular_opsz_coord(ttFont, regular_opsz_coord):
-    """The variable font 'opsz' (Optical Size) axis coordinate should be between 9 and 13 on the 'Regular' instance."""
+    """The variable font 'opsz' (Optical Size) axis coordinate should be between 10 and 16 on the 'Regular' instance."""
 
-    if regular_opsz_coord >= 9 and regular_opsz_coord <= 13:
+    if regular_opsz_coord >= 10 and regular_opsz_coord <= 16:
         yield PASS, ("Regular:opsz coordinate ({regular_opsz_coord}) looks good.")
     else:
         yield WARN,\
               Message("out-of-range",
                       f'The "opsz" (Optical Size) coordinate'
                       f' on the "Regular" instance is recommended'
-                      f' to be a value in the range 9 to 13.'
+                      f' to be a value in the range 10 to 16.'
                       f' Got {regular_opsz_coord} instead.')
 
 
@@ -151,9 +141,7 @@ def com_google_fonts_check_varfont_regular_opsz_coord(ttFont, regular_opsz_coord
     """,
     conditions = ['is_variable_font',
                   'bold_wght_coord'],
-    misc_metadata = {
-        'request': 'https://github.com/googlefonts/fontbakery/issues/1707'
-    }
+    proposal = 'https://github.com/googlefonts/fontbakery/issues/1707'
 )
 def com_google_fonts_check_varfont_bold_wght_coord(ttFont, bold_wght_coord):
     """The variable font 'wght' (Weight) axis coordinate must be 700 on the 'Bold' instance."""
@@ -176,9 +164,7 @@ def com_google_fonts_check_varfont_bold_wght_coord(ttFont, bold_wght_coord):
         On the 'wght' (Weight) axis, the valid coordinate range is 1-1000.
     """,
     conditions = ['is_variable_font'],
-    misc_metadata = {
-        'request': 'https://github.com/googlefonts/fontbakery/issues/2264'
-    }
+    proposal = 'https://github.com/googlefonts/fontbakery/issues/2264'
 )
 def com_google_fonts_check_varfont_wght_valid_range(ttFont):
     """The variable font 'wght' (Weight) axis coordinate
@@ -207,10 +193,11 @@ def com_google_fonts_check_varfont_wght_valid_range(ttFont):
 
         On the 'wdth' (Width) axis, the valid coordinate range is 1-1000
     """,
-    conditions = ['is_variable_font']
+    conditions = ['is_variable_font'],
+    proposal = 'https://github.com/googlefonts/fontbakery/pull/2520'
 )
 def com_google_fonts_check_varfont_wdth_valid_range(ttFont):
-    """The variable font 'wdth' (Weight) axis coordinate
+    """The variable font 'wdth' (Width) axis coordinate
        must be within spec range of 1 to 1000 on all instances."""
 
     Failed = False
@@ -238,9 +225,7 @@ def com_google_fonts_check_varfont_wdth_valid_range(ttFont):
     """,
     conditions = ['is_variable_font',
                   'slnt_axis'],
-    misc_metadata = {
-        'request': 'https://github.com/googlefonts/fontbakery/issues/2572'
-    }
+    proposal = 'https://github.com/googlefonts/fontbakery/issues/2572'
 )
 def com_google_fonts_check_varfont_slnt_range(ttFont, slnt_axis):
     """ The variable font 'slnt' (Slant) axis coordinate
