@@ -34,12 +34,10 @@ def _get_mark_class_glyphnames(ttFont):
         Glyphs in the GDEF mark glyph class should be non-spacing.
         Spacing glyphs in the GDEF mark glyph class may have incorrect anchor positioning that was only intended for building composite glyphs during design.
     """,
-    misc_metadata = {
-        'request': 'https://github.com/googlefonts/fontbakery/issues/2877'
-    }
+    proposal = 'https://github.com/googlefonts/fontbakery/issues/2877'
 )
-def com_google_fonts_check_gdef_spacing_marks(ttFont):
-    """Check mark characters are in GDEF mark glyph class)"""
+def com_google_fonts_check_gdef_spacing_marks(ttFont, config):
+    """Check glyphs in mark glyph class are non-spacing."""
     from fontbakery.utils import pretty_print_list
 
     if "GDEF" in ttFont and ttFont["GDEF"].table.GlyphClassDef:
@@ -48,10 +46,17 @@ def com_google_fonts_check_gdef_spacing_marks(ttFont):
                               if width > 0}
         mark_class_glyphnames = _get_mark_class_glyphnames(ttFont)
         spacing_glyphnames_in_mark_glyph_class = spacing_glyphnames & mark_class_glyphnames
-        if spacing_glyphnames_in_mark_glyph_class :
+        if spacing_glyphnames_in_mark_glyph_class:
+            cmap = ttFont['cmap'].getBestCmap()
+            glyphs = [f"{glyphname} (U+{codepoint:04X})"
+                      for codepoint, glyphname in cmap.items()
+                      if glyphname in spacing_glyphnames_in_mark_glyph_class]
+            glyphs += [f"{glyphname} (unencoded)"
+                       for glyphname in spacing_glyphnames_in_mark_glyph_class
+                       if glyphname not in cmap.values()]
             formatted_list = "\t " +\
-                             pretty_print_list(sorted(spacing_glyphnames_in_mark_glyph_class),
-                                               shorten=10,
+                             pretty_print_list(config,
+                                               sorted(glyphs),
                                                sep=", ")
             yield WARN,\
                   Message('spacing-mark-glyphs',
@@ -71,12 +76,10 @@ def com_google_fonts_check_gdef_spacing_marks(ttFont):
     rationale = """
         Mark characters should be in the GDEF mark glyph class.
     """,
-    misc_metadata = {
-        'request': 'https://github.com/googlefonts/fontbakery/issues/2877'
-    }
+    proposal = 'https://github.com/googlefonts/fontbakery/issues/2877'
 )
-def com_google_fonts_check_gdef_mark_chars(ttFont):
-    """Check mark characters are in GDEF mark glyph class"""
+def com_google_fonts_check_gdef_mark_chars(ttFont, config):
+    """Check mark characters are in GDEF mark glyph class."""
     from fontbakery.utils import pretty_print_list
 
     if "GDEF" in ttFont and ttFont["GDEF"].table.GlyphClassDef:
@@ -90,9 +93,9 @@ def com_google_fonts_check_gdef_mark_chars(ttFont):
 
         if mark_chars_not_in_mark_class:
             formatted_marks = "\t " +\
-                pretty_print_list(sorted("U+%04X" % c for c in
-                                         mark_chars_not_in_mark_class),
-                                  shorten=None,
+                pretty_print_list(config,
+                                  sorted(f"{cmap[c]} (U+{c:04X})"
+                                         for c in mark_chars_not_in_mark_class),
                                   sep=", ")
             yield WARN,\
                   Message('mark-chars',
@@ -113,12 +116,10 @@ def com_google_fonts_check_gdef_mark_chars(ttFont):
         Glyphs in the GDEF mark glyph class become non-spacing and may be repositioned if they have mark anchors.
         Only combining mark glyphs should be in that class. Any non-mark glyph must not be in that class, in particular spacing glyphs.
     """,
-    misc_metadata = {
-        'request': 'https://github.com/googlefonts/fontbakery/issues/2877'
-    }
+    proposal = 'https://github.com/googlefonts/fontbakery/issues/2877'
 )
-def com_google_fonts_check_gdef_non_mark_chars(ttFont):
-    """Check GDEF mark glyph class doesn't have characters that are not marks)"""
+def com_google_fonts_check_gdef_non_mark_chars(ttFont, config):
+    """Check GDEF mark glyph class doesn't have characters that are not marks."""
     from fontbakery.utils import pretty_print_list
 
     if "GDEF" in ttFont and ttFont["GDEF"].table.GlyphClassDef:
@@ -144,9 +145,9 @@ def com_google_fonts_check_gdef_non_mark_chars(ttFont):
                     if char in nonmark_chars:
                         nonmark_chars_in_mark_class.add(char)
             formatted_nonmarks = "\t " +\
-                                 pretty_print_list(sorted("U+%04X" % c for c in
+                                 pretty_print_list(config,
+                                                   sorted("U+%04X" % c for c in
                                                           nonmark_chars_in_mark_class),
-                                                   shorten=None,
                                                    sep=", ")
             yield WARN,\
                   Message('non-mark-chars',
