@@ -1,5 +1,6 @@
 import os
 import re
+import yaml
 
 from fontbakery.callable import condition
 from fontbakery.constants import (
@@ -24,12 +25,16 @@ def style(font):
 
 
 @condition
-def RIBBI_ttFonts(fonts):
-    from fontTools.ttLib import TTFont
+def RIBBI_ttFonts(ttFonts):
     from fontbakery.constants import RIBBI_STYLE_NAMES
-    return [TTFont(f)
-            for f in fonts
-            if style(f) in RIBBI_STYLE_NAMES]
+    return [ttFont for ttFont in ttFonts
+            if style(ttFont.reader.file.name) in RIBBI_STYLE_NAMES]
+
+
+@condition
+def glyphsFile(glyphs_file):
+    import glyphsLib
+    return glyphsLib.load(open(glyphs_file))
 
 
 @condition
@@ -143,21 +148,53 @@ def description(descfile):
 
 
 @condition
-def metadata_file(family_directory):
-    if family_directory:
+def readme_directory(readme_md):
+    if not readme_md:
+        return
+    if isinstance(readme_md, list):
+        # It makes no sense to deal with more than a single README.md file
+        # This here is just a quirk of the way we handle fontbakery inputs nowadays.
+        readme_md = readme_md[0]
+    return os.path.dirname(readme_md)
+
+
+@condition
+def readme_contents(readme_md):
+    """Get the contents of the README.md file of a font project."""
+    if not readme_md:
+        return
+    if isinstance(readme_md, list):
+        readme_md = readme_md[0]        # quirk
+    return open(readme_md, "r", encoding="utf-8").read()
+
+
+@condition
+def metadata_file(family_directory,
+                  metadata_pb=None):
+    if metadata_pb:
+        if isinstance(metadata_pb, list):
+            metadata_pb = metadata_pb[0]        # quirk
+
+        return metadata_pb
+
+    elif family_directory:
         pb_file = os.path.join(family_directory, "METADATA.pb")
         if os.path.exists(pb_file):
             return pb_file
 
+
 @condition
 def family_metadata(metadata_file):
+    if not metadata_file:
+        return
+
     from google.protobuf import text_format
     from fontbakery.utils import get_FamilyProto_Message
-    if metadata_file:
-      try:
-          return get_FamilyProto_Message(metadata_file)
-      except text_format.ParseError:
-          return None
+    try:
+        return get_FamilyProto_Message(metadata_file)
+    except text_format.ParseError:
+        return None
+
 
 @condition
 def registered_vendor_ids():
@@ -272,6 +309,10 @@ def license(license_path):
     if license_path:
         return os.path.basename(license_path)
 
+@condition
+def is_ofl(license):
+    return license and "OFL" in license
+
 
 @condition
 def familyname(font):
@@ -286,22 +327,6 @@ def familyname(font):
         return filename_base
 
 
-@condition
-def installed_ttfa():
-   import subprocess
-   ttfa_cmd = ["ttfautohint",
-               "-V"]  # print version info
-   try:
-       ttfa_output = subprocess.check_output(ttfa_cmd,
-                                             stderr=subprocess.STDOUT)
-   except FileNotFoundError:
-       return None
-
-   installed = re.search(r'ttfautohint ([^-\n]*)(-.*)?\n',
-                         ttfa_output.decode('utf-8')).group(1)
-   return installed
-
-
 @condition
 def hinting_stats(font):
     """
@@ -414,20 +439,53 @@ def font_familyname(font_familynames):
     return font_familynames[0]
 
 
-# TODO: Design special case handling for whitelists/blacklists
+# TODO: Design special case handling mechanism:
 # https://github.com/googlefonts/fontbakery/issues/1540
+# TODO: Improve camelcase check result explanation and whitelisting process:
+#https://github.com/googlefonts/fontbakery/issues/3270
 @condition
-def whitelist_camelcased_familyname(font):
-    familynames = [
+def camelcased_familyname_exception(familyname):
+    '''In general, we would not like to have camel-cased
+       familynames but there are a few exceptions to that
+       rule, that we keep listed here, for now.
+    '''
+    for exception in [
+        "3D", # seen in "Rock 3D"
+        "ABeeZee",
         "BenchNine",
+        "BhuTuka", # seen in "BhuTuka Expanded One"
+        "DotGothic", # seen in "DotGothic16"
         "FakeFont",
+        "JetBrains", # seen in "JetBrains Mono"
         "McLaren",
         "MedievalSharp",
+        "RocknRoll", # seen in "RocknRoll One"
+        "BIZ UDGothic",
+        "BIZ UDPGothic",
+        "BIZ UDMincho",
+        "BIZ UDPMincho",
         "UnifrakturCook",
-        "UnifrakturMaguntia"
-    ]
-    for familyname in familynames:
-        if familyname in font:
+        "UnifrakturMaguntia",
+        "MonteCarlo",
+        "WindSong",
+    ]:
+        if exception in familyname:
+            return True
+
+@condition
+def rfn_exception(familyname):
+    '''These are the very few font families where we accept usage of
+       a Reserved Font Name. These are typically fonts that had already
+       been published previously with an RFN, or fonts which benefit from
+       an agreement with Google Fonts.
+    '''
+    RNF_EXCEPTIONS = [] # For now we'll leave this empty because the
+                        # actual long list of familynames we had here
+                        # still needs to be more carefully reviewed.
+                        # See https://github.com/googlefonts/fontbakery/issues/3612
+
+    for exception in RNF_EXCEPTIONS:
+        if exception in familyname:
             return True
 
 
@@ -638,42 +696,20 @@ def gfonts_repo_structure(fonts):
 @condition
 def production_metadata():
     """Get the Google Fonts production metadata"""
-    import json
     import requests
     meta_url = "http://fonts.google.com/metadata/fonts"
-    # can't do requests.get("url").json() since request text starts with ")]}'"
-    return json.loads(requests.get(meta_url).text[5:])
+    return requests.get(meta_url).json()
 
 
 @condition
 def GFAxisRegistry():
-    from fontbakery.axes_pb2 import AxisProto
-    from fontbakery.utils import get_Protobuf_Message
-    from pkg_resources import resource_filename
+    from axisregistry import AxisRegistry
+    return AxisRegistry()
 
-    def normalize_name(name):
-        return ''.join(name.split(' '))
 
-    registry = {}
-    def append_AxisMessage(path):
-        axis_dict = {"message": get_Protobuf_Message(AxisProto, path),
-                     "fallbacks": {}}
-        for fb in axis_dict["message"].fallback:
-            axis_dict["fallbacks"][normalize_name(fb.name)] = fb.value
-        registry[axis_dict["message"].tag] = axis_dict
-
-    for axis in ["casual.textproto",
-                 "cursive.textproto",
-                 "flair.textproto",
-                 "grade.textproto",
-                 "italic.textproto",
-                 "monospace.textproto",
-                 "optical_size.textproto",
-                 "slant.textproto",
-                 "softness.textproto",
-                 "volume.textproto",
-                 "weight.textproto",
-                 "width.textproto",
-                 "wonky.textproto"]:
-        append_AxisMessage(resource_filename('fontbakery', 'data/' + axis))
-    return registry
+@condition
+def upstream_yaml(family_directory):
+    fp = os.path.join(family_directory, "upstream.yaml")
+    if not os.path.isfile(fp):
+        return None
+    return yaml.load(open(fp, "r"), yaml.FullLoader)
