@@ -20,6 +20,7 @@ OPENTYPE_PROFILE_IMPORTS = (
         "glyf",
         "fvar",
         "stat",
+        "layout",
         "shared_conditions",
     ),
 )
@@ -72,9 +73,11 @@ OPENTYPE_PROFILE_CHECKS = [
     'com.google.fonts/check/maxadvancewidth',
     'com.google.fonts/check/points_out_of_bounds',
     'com.google.fonts/check/glyf_non_transformed_duplicate_components',
-    'com.google.fonts/check/glyf_nested_components',
     'com.google.fonts/check/all_glyphs_have_codepoints',
     'com.google.fonts/check/code_pages',
+    'com.google.fonts/check/layout_valid_feature_tags',
+    'com.google.fonts/check/layout_valid_script_tags',
+    'com.google.fonts/check/layout_valid_language_tags',
 ]
 
 profile.auto_register(globals())
