@@ -10,7 +10,8 @@ profile_imports = [
 ]
 
 @check(
-    id = 'com.google.fonts/check/family/panose_proportion'
+    id = 'com.google.fonts/check/family/panose_proportion',
+    proposal = 'legacy:check/009'
 )
 def com_google_fonts_check_family_panose_proportion(ttFonts):
     """Fonts have consistent PANOSE proportion?"""
@@ -44,7 +45,8 @@ def com_google_fonts_check_family_panose_proportion(ttFonts):
 
 
 @check(
-    id = 'com.google.fonts/check/family/panose_familytype'
+    id = 'com.google.fonts/check/family/panose_familytype',
+    proposal = 'legacy:check/010'
 )
 def com_google_fonts_check_family_panose_familytype(ttFonts):
     """Fonts have consistent PANOSE family type?"""
@@ -80,7 +82,8 @@ def com_google_fonts_check_family_panose_familytype(ttFonts):
 
 @check(
     id = 'com.google.fonts/check/xavgcharwidth',
-    conditions = ['is_ttf']
+    conditions = ['is_ttf'],
+    proposal = 'legacy:check/034'
 )
 def com_google_fonts_check_xavgcharwidth(ttFont):
     """Check if OS/2 xAvgCharWidth is correct."""
@@ -188,7 +191,8 @@ def com_google_fonts_check_xavgcharwidth(ttFont):
     id = 'com.adobe.fonts/check/fsselection_matches_macstyle',
     rationale = """
         The bold and italic bits in OS/2.fsSelection must match the bold and italic bits in head.macStyle per the OpenType spec.
-    """
+    """,
+    proposal = 'https://github.com/googlefonts/fontbakery/pull/2382'
 )
 def com_adobe_fonts_check_fsselection_matches_macstyle(ttFont):
     """Check if OS/2 fsSelection matches head macStyle bold and italic bits."""
@@ -236,7 +240,8 @@ def com_adobe_fonts_check_fsselection_matches_macstyle(ttFont):
         Per the OpenType spec: name ID 1 'is used in combination with Font Subfamily name (name ID 2), and should be shared among at most four fonts that differ only in weight or style...
 
         This four-way distinction should also be reflected in the OS/2.fsSelection field, using bits 0 and 5.
-    """
+    """,
+    proposal = 'https://github.com/googlefonts/fontbakery/pull/2388'
 )
 def com_adobe_fonts_check_family_bold_italic_unique_for_nameid1(RIBBI_ttFonts):
     """Check that OS/2.fsSelection bold & italic settings are unique
@@ -289,7 +294,8 @@ def com_adobe_fonts_check_family_bold_italic_unique_for_nameid1(RIBBI_ttFonts):
         This check currently does not identify which code pages should be set. Auto-detecting coverage is not trivial since the OpenType specification leaves the interpretation of whether a given code page is "functional" or not open to the font developer to decide.
 
         So here we simply detect as a FAIL when a given font has no code page declared at all.
-    """
+    """,
+    proposal = 'https://github.com/googlefonts/fontbakery/issues/2474'
 )
 def com_google_fonts_check_code_pages(ttFont):
     """Check code page character ranges"""
