@@ -20,7 +20,9 @@ FALSE_POSITIVE_CUTOFF = 100  # More than this and we don't make a report
 
 @condition
 def outlines_dict(ttFont):
-    return {g: BezierPath.fromFonttoolsGlyph(ttFont, g) for g in ttFont.getGlyphOrder()}
+    cmap = ttFont['cmap'].getBestCmap()
+    return {(codepoint, glyphname): BezierPath.fromFonttoolsGlyph(ttFont, glyphname)
+            for codepoint, glyphname in cmap.items()}
 
 
 def close_but_not_on(yExpected, yTrue, tolerance):
@@ -38,9 +40,10 @@ def close_but_not_on(yExpected, yTrue, tolerance):
 
         Not all such misaligned curve points are a mistake, and sometimes the design may call for points in locations near the boundaries. As this check is liable to generate significant numbers of false positives, it will pass if there are more than {FALSE_POSITIVE_CUTOFF} reported misalignments.
     """,
-    conditions = ["outlines_dict"]
+    conditions = ["outlines_dict"],
+    proposal = 'https://github.com/googlefonts/fontbakery/pull/3088'
 )
-def com_google_fonts_check_outline_alignment_miss(ttFont, outlines_dict):
+def com_google_fonts_check_outline_alignment_miss(ttFont, outlines_dict, config):
     """Are there any misaligned on-curve points?"""
     alignments = {
         "baseline": 0,
@@ -50,7 +53,8 @@ def com_google_fonts_check_outline_alignment_miss(ttFont, outlines_dict):
         "descender": ttFont["OS/2"].sTypoDescender,
     }
     warnings = []
-    for glyphname, outlines in outlines_dict.items():
+    for glyph, outlines in outlines_dict.items():
+        codepoint, glyphname = glyph
         for p in outlines:
             for node in p.asNodelist():
                 if node.type == "offcurve":
@@ -62,7 +66,8 @@ def com_google_fonts_check_outline_alignment_miss(ttFont, outlines_dict):
                     ):
                         continue
                     if close_but_not_on(yExpected, node.y, ALIGNMENT_MISS_EPSILON):
-                        warnings.append(f"{glyphname}: X={node.x},Y={node.y}"
+                        warnings.append(f"{glyphname} (U+{codepoint:04X}):"
+                                        f" X={node.x},Y={node.y}"
                                         f" (should be at {line} {yExpected}?)")
         if len(warnings) > FALSE_POSITIVE_CUTOFF:
             # Let's not waste time.
@@ -71,7 +76,9 @@ def com_google_fonts_check_outline_alignment_miss(ttFont, outlines_dict):
             return
 
     if warnings:
-        formatted_list = "\t* " + pretty_print_list(warnings, sep="\n\t* ")
+        formatted_list = "\t* " + pretty_print_list(config,
+                                                    warnings,
+                                                    sep="\n\t* ")
         yield WARN,\
               Message("found-misalignments",
                       f"The following glyphs have on-curve points which"
@@ -84,17 +91,19 @@ def com_google_fonts_check_outline_alignment_miss(ttFont, outlines_dict):
 @check(
     id = "com.google.fonts/check/outline_short_segments",
     rationale = f"""
-        This check looks for outline segments which seem particularly short (less than {SHORT_PATH_EPSILON}%% of the overall path length).
+        This check looks for outline segments which seem particularly short (less than {SHORT_PATH_EPSILON:.1%} of the overall path length).
 
         This check is not run for variable fonts, as they may legitimately have short segments. As this check is liable to generate significant numbers of false positives, it will pass if there are more than {FALSE_POSITIVE_CUTOFF} reported short segments.
     """,
     conditions = ["outlines_dict",
-                  "is_not_variable_font"]
+                  "is_not_variable_font"],
+    proposal = 'https://github.com/googlefonts/fontbakery/pull/3088'
 )
-def com_google_fonts_check_outline_short_segments(ttFont, outlines_dict):
+def com_google_fonts_check_outline_short_segments(ttFont, outlines_dict, config):
     """Are any segments inordinately short?"""
     warnings = []
-    for glyphname, outlines in outlines_dict.items():
+    for glyph, outlines in outlines_dict.items():
+        codepoint, glyphname = glyph
         for p in outlines:
             outline_length = p.length
             segments = p.asSegments()
@@ -103,12 +112,14 @@ def com_google_fonts_check_outline_short_segments(ttFont, outlines_dict):
             prev_was_line = len(segments[-1]) == 2
             for seg in p.asSegments():
                 if math.isclose(seg.length, 0):  # That's definitely wrong
-                    warnings.append(f"{glyphname} contains a short segment {seg}")
+                    warnings.append(f"{glyphname} (U+{codepoint:04X})"
+                                    f" contains a short segment {seg}")
                 elif (
                     seg.length < SHORT_PATH_ABSOLUTE_EPSILON
                     or seg.length < SHORT_PATH_EPSILON * outline_length
                 ) and (prev_was_line or len(seg) > 2):
-                    warnings.append(f"{glyphname} contains a short segment {seg}")
+                    warnings.append(f"{glyphname} (U+{codepoint:04X})"
+                                    f" contains a short segment {seg}")
                 prev_was_line = len(seg) == 2
         if len(warnings) > FALSE_POSITIVE_CUTOFF:
             yield PASS, ("So many short segments were found"
@@ -116,7 +127,9 @@ def com_google_fonts_check_outline_short_segments(ttFont, outlines_dict):
             return
 
     if warnings:
-        formatted_list = "\t* " + pretty_print_list(warnings, sep="\n\t* ")
+        formatted_list = "\t* " + pretty_print_list(config,
+                                                    warnings,
+                                                    sep="\n\t* ")
         yield WARN,\
               Message("found-short-segments",
                       f"The following glyphs have segments which seem very short:\n"
@@ -133,12 +146,14 @@ def com_google_fonts_check_outline_short_segments(ttFont, outlines_dict):
         This check is not run for variable fonts, as they may legitimately have colinear vectors.
     """,
     conditions = ["outlines_dict",
-                  "is_not_variable_font"]
+                  "is_not_variable_font"],
+    proposal = 'https://github.com/googlefonts/fontbakery/pull/3088'
 )
-def com_google_fonts_check_outline_colinear_vectors(ttFont, outlines_dict):
+def com_google_fonts_check_outline_colinear_vectors(ttFont, outlines_dict, config):
     """Do any segments have colinear vectors?"""
     warnings = []
-    for glyphname, outlines in outlines_dict.items():
+    for glyph, outlines in outlines_dict.items():
+        codepoint, glyphname = glyph
         for p in outlines:
             segments = p.asSegments()
             if not segments:
@@ -151,14 +166,17 @@ def com_google_fonts_check_outline_colinear_vectors(ttFont, outlines_dict):
                         abs(prev.tangentAtTime(0).angle - this.tangentAtTime(0).angle)
                         < COLINEAR_EPSILON
                     ):
-                        warnings.append(f"{glyphname}: {prev} -> {this}")
+                        warnings.append(f"{glyphname} (U+{codepoint:04X}):"
+                                        f" {prev} -> {this}")
         if len(warnings) > FALSE_POSITIVE_CUTOFF:
             yield PASS, ("So many colinear vectors were found"
                          " that this was probably by design.")
             return
 
     if warnings:
-        formatted_list = "\t* " + pretty_print_list(sorted(set(warnings)), sep="\n\t* ")
+        formatted_list = "\t* " + pretty_print_list(config,
+                                                    sorted(set(warnings)),
+                                                    sep="\n\t* ")
         yield WARN,\
               Message("found-colinear-vectors",
                       f"The following glyphs have colinear vectors:\n"
@@ -174,14 +192,13 @@ def com_google_fonts_check_outline_colinear_vectors(ttFont, outlines_dict):
     """,
     conditions = ["outlines_dict",
                   "is_not_variable_font"],
-    misc_metadata = {
-        'request': 'https://github.com/googlefonts/fontbakery/issues/3064'
-    }
+    proposal = 'https://github.com/googlefonts/fontbakery/issues/3064'
 )
-def com_google_fonts_check_outline_jaggy_segments(ttFont, outlines_dict):
+def com_google_fonts_check_outline_jaggy_segments(ttFont, outlines_dict, config):
     """Do outlines contain any jaggy segments?"""
     warnings = []
-    for glyphname, outlines in outlines_dict.items():
+    for glyph, outlines in outlines_dict.items():
+        codepoint, glyphname = glyph
         for p in outlines:
             segments = p.asSegments()
             if not segments:
@@ -201,11 +218,13 @@ def com_google_fonts_check_outline_jaggy_segments(ttFont, outlines_dict):
                 jag_angle = math.acos(angle)
                 if abs(jag_angle) > JAG_ANGLE or jag_angle == 0:
                     continue
-                warnings.append(f"{glyphname}:"
+                warnings.append(f"{glyphname} (U+{codepoint:04X}):"
                                 f" {prev}/{this} = {math.degrees(jag_angle)}")
 
     if warnings:
-        formatted_list = "\t* " + pretty_print_list(sorted(warnings), sep="\n\t* ")
+        formatted_list = "\t* " + pretty_print_list(config,
+                                                    sorted(warnings),
+                                                    sep="\n\t* ")
         yield WARN,\
               Message("found-jaggy-segments",
                       f"The following glyphs have jaggy segments:\n"
@@ -223,12 +242,14 @@ def com_google_fonts_check_outline_jaggy_segments(ttFont, outlines_dict):
     """,
     conditions = ["outlines_dict",
                   "is_not_variable_font",
-                  "is_not_italic"]
+                  "is_not_italic"],
+    proposal = 'https://github.com/googlefonts/fontbakery/pull/3088'
 )
-def com_google_fonts_check_outline_semi_vertical(ttFont, outlines_dict):
+def com_google_fonts_check_outline_semi_vertical(ttFont, outlines_dict, config):
     """Do outlines contain any semi-vertical or semi-horizontal lines?"""
     warnings = []
-    for glyphname, outlines in outlines_dict.items():
+    for glyph, outlines in outlines_dict.items():
+        codepoint, glyphname = glyph
         for p in outlines:
             segments = p.asSegments()
             if not segments:
@@ -239,10 +260,12 @@ def com_google_fonts_check_outline_semi_vertical(ttFont, outlines_dict):
                 angle = math.degrees((s.end - s.start).angle)
                 for yExpected in [-180, -90, 0, 90, 180]:
                     if close_but_not_on(angle, yExpected, 0.5):
-                        warnings.append(f"{glyphname}: {s}")
+                        warnings.append(f"{glyphname} (U+{codepoint:04X}): {s}")
 
     if warnings:
-        formatted_list = " * " + pretty_print_list(sorted(warnings), sep="\n * ")
+        formatted_list = " * " + pretty_print_list(config,
+                                                   sorted(warnings),
+                                                   sep="\n * ")
         yield WARN,\
              Message("found-semi-vertical",
                      f"The following glyphs have semi-vertical/semi-horizontal lines:\n"
