@@ -1,5 +1,6 @@
 import os
 from fontbakery.reporters.serialize import SerializeReporter
+from fontbakery.utils import html5_collapsible
 from fontbakery.checkrunner import Status
 from fontbakery import __version__ as version
 
@@ -8,10 +9,6 @@ LOGLEVELS=["ERROR","FAIL","WARN","SKIP","INFO","PASS","DEBUG"]
 
 class GHMarkdownReporter(SerializeReporter):
 
-    def __init__(self, loglevels, **kwd):
-        super().__init__(**kwd)
-        self.loglevels = loglevels
-
     def write(self):
         with open(self.output_file, "w") as fh:
             fh.write(self.get_markdown())
@@ -32,13 +29,6 @@ class GHMarkdownReporter(SerializeReporter):
         }[name]
 
 
-    def html5_collapsible(self, summary, details):
-        return (f"<details>\n"
-                f"<summary>{summary}</summary>\n"
-                f"{details}\n"
-                f"</details>\n")
-
-
     def log_md(self, log):
         if not self.omit_loglevel(log["status"]):
             return "* {} **{}** {}\n".format(self.emoticon(log["status"]),
@@ -49,18 +39,12 @@ class GHMarkdownReporter(SerializeReporter):
 
 
     def render_rationale(self, check, checkid):
-        if not "rationale" in check:
+        if self.succinct or not "rationale" in check:
             return ""
 
-        # Ideally we'll at some point invoke a proper markdown
-        # parser here. But for now, let's simply fill the raw
-        # content into an 80-column block of text and output it
-        # enclosed in <pre></pre> tags...
-        import html
-        from fontbakery.utils import text_flow, unindent_rationale
+        from fontbakery.utils import unindent_rationale
         content = unindent_rationale(check['rationale'], checkid)
-        rationale = html.escape(text_flow(content, 80))
-        return f"<pre>--- Rationale ---\n{rationale}</pre>\n"
+        return "\n".join([ ">" + line for line in content.split("\n")])
 
     def check_md(self, check):
         checkid = check["key"][1].split(":")[1].split(">")[0]
@@ -68,20 +52,17 @@ class GHMarkdownReporter(SerializeReporter):
 
         check["logs"].sort(key=lambda c: c["status"])
         logs = "".join(map(self.log_md, check["logs"]))
-        github_search_url = (f"[{checkid}]"
-                             f"(https://font-bakery.readthedocs.io/en/latest"
-                             f"/fontbakery/profiles/{profile}.html#{checkid})")
+        github_search_url = ( "<a href=\"https://font-bakery.readthedocs.io/en/latest"
+                             f"/fontbakery/profiles/{profile}.html#{checkid}\">"
+                             f"{checkid}</a>" )
 
         rationale = self.render_rationale(check, checkid)
 
-        return self.html5_collapsible("{} <b>{}:</b> {}".format(self.emoticon(check["result"]),
+        return html5_collapsible("{} <b>{}:</b> {} ({})".format(self.emoticon(check["result"]),
                                                                 check["result"],
-                                                                check["description"]),
-                                      f"\n* {github_search_url}\n{rationale}\n{logs}")
-
-    def omit_loglevel(self, msg):
-        return self.loglevels and (self.loglevels[0] > Status(msg))
-
+                                                                check["description"],
+                                                                github_search_url),
+                                      f"\n\n{rationale}\n{logs}")
 
     def deduce_profile_from_section_name(self, section):
         # This is very hacky!
@@ -95,6 +76,10 @@ class GHMarkdownReporter(SerializeReporter):
         if 'fontbakery.profiles.' in section: return section.split('fontbakery.profiles.')[1].split('>')[0]
         return section
 
+    def result_is_all_same(self, cluster):
+        first_check = cluster[0]
+        return all(check["logs"] == first_check["logs"] for check in cluster[1:])
+
 
     def get_markdown(self):
         checks = {}
@@ -106,6 +91,10 @@ class GHMarkdownReporter(SerializeReporter):
                 if not isinstance(cluster, list):
                     cluster = [cluster]
                 num_checks += len(cluster)
+                if len(cluster) > 1 and self.result_is_all_same(cluster):
+                    # Pretend it's a family check
+                    cluster = [cluster[0]]
+                    del cluster[0]["filename"]
                 for check in cluster:
                     if self.omit_loglevel(check["result"]):
                         continue
@@ -127,12 +116,12 @@ class GHMarkdownReporter(SerializeReporter):
 
         if family_checks:
             family_checks.sort(key=lambda c: c["result"])
-            md += self.html5_collapsible("<b>[{}] Family checks</b>".format(len(family_checks)),
+            md += html5_collapsible("<b>[{}] Family checks</b>".format(len(family_checks)),
                                          "".join(map(self.check_md, family_checks)) + "<br>")
 
         for filename in checks.keys():
             checks[filename].sort(key=lambda c: LOGLEVELS.index(c["result"]))
-            md += self.html5_collapsible("<b>[{}] {}</b>".format(len(checks[filename]),
+            md += html5_collapsible("<b>[{}] {}</b>".format(len(checks[filename]),
                                                                  filename),
                                          "".join(map(self.check_md, checks[filename])) + "<br>")
 
