@@ -8,7 +8,8 @@ from cmarkgfm.cmark import Options as cmarkgfmOptions
 
 
 import fontbakery.checkrunner
-import fontbakery.reporters.serialize
+from fontbakery.reporters.serialize import SerializeReporter
+from fontbakery.utils import unindent_rationale, html5_collapsible
 
 LOGLEVELS = ["ERROR", "FAIL", "WARN", "SKIP", "INFO", "PASS", "DEBUG"]
 EMOTICON = {
@@ -23,12 +24,9 @@ EMOTICON = {
 ISSUE_URL = "https://github.com/googlefonts/fontbakery/issues"
 
 
-class HTMLReporter(fontbakery.reporters.serialize.SerializeReporter):
+class HTMLReporter(SerializeReporter):
     """Renders a report as a HTML document."""
 
-    def __init__(self, loglevels, **kwd):
-        super().__init__(**kwd)
-
     def write(self):
         with open(self.output_file, "w", encoding="utf-8") as fh:
             fh.write(self.get_html())
@@ -47,6 +45,8 @@ class HTMLReporter(fontbakery.reporters.serialize.SerializeReporter):
             section_stati_of_note = (
                 e for e in section["result"].elements() if e != "PASS"
             )
+            if all([self.omit_loglevel(s) for s in section["result"].elements()]):
+                continue
             section_stati = "".join(
                 EMOTICON[s] for s in sorted(section_stati_of_note, key=LOGLEVELS.index)
             )
@@ -63,10 +63,15 @@ class HTMLReporter(fontbakery.reporters.serialize.SerializeReporter):
                 for check in cluster:
                     checks_by_id[check["key"][1]].append(check)
             for check, results in checks_by_id.items():
+                if all([self.omit_loglevel(result['result']) for result in results]):
+                    continue
                 check_name = html.escape(check)
                 body_elements.append(f"<h3>{results[0]['description']}</h3>")
                 body_elements.append(f"<div>Check ID: {check_name}</div>")
+                body_elements.append(self.render_rationale(results[0], check))
                 for result in results:
+                    if self.omit_loglevel(result['result']):
+                        continue
                     if "filename" in result:
                         body_elements.append(
                             html5_collapsible(
@@ -104,18 +109,20 @@ class HTMLReporter(fontbakery.reporters.serialize.SerializeReporter):
         body_elements[0:0] = body_top
         return html5_document(body_elements)
 
-    def omit_loglevel(self, msg) -> bool:
-        """Determine if message is below log level."""
-        return self.loglevels and (
-            self.loglevels[0] > fontbakery.checkrunner.Status(msg)
-        )
-
     def html_for_check(self, check) -> str:
         """Return HTML string for complete single check."""
         check["logs"].sort(key=lambda c: LOGLEVELS.index(c["status"]))
         logs = "<ul>" + "".join([self.log_html(log) for log in check["logs"]]) + "</ul>"
         return logs
 
+    def render_rationale(self, check, checkid) -> str:
+        if self.succinct or "rationale" not in check:
+            return ""
+        content = unindent_rationale(check['rationale'], checkid)
+        return cmarkgfm.markdown_to_html(
+                content, options=cmarkgfmOptions.CMARK_OPT_UNSAFE
+        )
+
     def log_html(self, log) -> str:
         """Return single check sub-result string as HTML or not if below log
         level."""
@@ -205,13 +212,6 @@ def html5_document(body_elements) -> str:
                 </html>"""
 
 
-def html5_collapsible(summary, details) -> str:
-    """Return nestable, collapsible <detail> tag for check grouping and sub-
-    results."""
-
-    return f"<details><summary>{summary}</summary><div>{details}</div></details>"
-
-
 def summary_table(
     errors: int, fails: int, warns: int, skips: int, infos: int, passes: int, debugs: int, total: int
 ) -> str:
