@@ -18,6 +18,7 @@ from fontbakery.checkrunner import (
             , END
             )
 from fontbakery.reporters import FontbakeryReporter
+from fontbakery.checkrunner import Status
 
 class SerializeReporter(FontbakeryReporter):
     """
@@ -29,9 +30,13 @@ class SerializeReporter(FontbakeryReporter):
     """
 
 
-    def __init__(self, collect_results_by=None
-                     , **kwd):
+    def __init__(self, loglevels,
+                     succinct=None,
+                     collect_results_by=None,
+                     **kwd):
         super().__init__(**kwd)
+        self.succinct = succinct
+        self.loglevels = loglevels
         self._results_by = collect_results_by
         self._items = {}
         self._doc = None
@@ -48,6 +53,12 @@ class SerializeReporter(FontbakeryReporter):
         # otherwise this `check`
         pass
 
+    def omit_loglevel(self, msg) -> bool:
+        """Determine if message is below log level."""
+        return self.loglevels and (
+            self.loglevels[0] > Status(msg)
+        )
+
     def _register(self, event):
         super()._register(event)
         status, message, identity = event
@@ -99,6 +110,8 @@ class SerializeReporter(FontbakeryReporter):
             item['description'] = check.description
             if check.rationale:
                 item['rationale'] = check.rationale
+            if check.severity:
+                item['severity'] = check.severity
             if item["key"][2] != ():
                 item['filename'] = self.runner.get_iterarg(*item["key"][2][0])
 
