@@ -17,8 +17,11 @@ import os
 import sys
 
 from fontTools.ttLib import TTFont
+from fontTools.unicodedata import ot_tag_to_script
 from typing import Text, Optional
 from fontbakery.constants import NO_COLORS_THEME, DARK_THEME, LIGHT_THEME
+from ufo2ft.constants import INDIC_SCRIPTS, USE_SCRIPTS
+from vharfbuzz import Vharfbuzz
 
 
 
@@ -37,8 +40,10 @@ def colorless_len(str):
     import re
     return len(re.sub('\x1b(\\[[0-9;]+|\\].+)m', '', str))
 
-def text_flow(content, width=80, indent=0, left_margin=0, first_line_indent=0,
-              space_padding=False, text_color="{}".format):
+
+def text_flow(content, width=80, indent=0, left_margin=0,
+              first_line_indent=0, space_padding=False,
+              text_color="{}".format): # pylint: disable=consider-using-f-string
     result = []
     line_num = 0
     for line in content.split("\n"):
@@ -117,6 +122,13 @@ def unindent_rationale(rationale, checkid=None):
     return content
 
 
+def html5_collapsible(summary, details) -> str:
+    """Return nestable, collapsible <detail> tag for check grouping and sub-
+    results."""
+
+    return f"<details><summary>{summary}</summary><div>{details}</div></details>"
+
+
 def split_camel_case(camelcase):
     result = []
     word = ""
@@ -141,25 +153,30 @@ def suffix(font):
     return '-'.join(s)
 
 
-def pretty_print_list(values, shorten=10, sep=", ", glue="and"):
+def pretty_print_list(config, values, shorten=10, sep=", ", glue="and"):
     if len(values) == 1:
         return str(values[0])
 
+    if config['full_lists']:
+        shorten = None
+
     if shorten and len(values) > shorten + 2:
-        return "{} {} {} more.".format(sep.join(map(str, values[:shorten])),
-                                       glue,
-                                       len(values) - shorten)
+        sep = sep.join(map(str, values[:shorten]))
+        return (f"{sep} {glue} {len(values) - shorten} more.\n"
+                f"\n"
+                f"Use -F or --full-lists to disable shortening of long lists.")
     else:
-        return "{} {} {}".format(sep.join(map(str, values[:-1])),
-                                 glue,
-                                 str(values[-1]))
+        sep = sep.join(map(str, values[:-1]))
+        return f"{sep} {glue} {str(values[-1])}"
 
 
-def bullet_list(values, bullet="-"):
-    return f" {bullet} " + pretty_print_list(values,
-                                             shorten=False,
-                                             sep=f"\n {bullet} ",
-                                             glue=f"\n {bullet}")
+def bullet_list(config, items, bullet="-", indentation="\t"):
+    return f"{indentation}{bullet} " +\
+           pretty_print_list(config,
+                             items,
+                             sep=f"\n{indentation}{bullet} ",
+                             glue=f"\n{indentation}{bullet} And")
+
 
 def get_regular(fonts):
     # TODO: Maybe also support getting a regular instance from a variable font?
@@ -176,6 +193,15 @@ def get_absolute_path(p):
     return abspath
 
 
+def filesize_formatting(s):
+    if s < 1024:
+        return f"{s} bytes"
+    elif s < 1024*1024:
+        return f"{s/1024:.1f}kb"
+    else:
+        return f"{s/(1024*1024):.1f}Mb"
+
+
 def get_bounding_box(font):
     """ Returns max and min bbox of given truetype font """
     ymin = 0
@@ -223,7 +249,7 @@ def name_entry_id(name):
     return "[{}({}):{}({})]".format(NameID(name.nameID).name,
                                     name.nameID,
                                     PlatformID(name.platformID).name,
-                                    name.platformID)
+                                    name.platformID) # pylint: disable=consider-using-f-string
 
 
 def get_glyph_name(font: TTFont, codepoint: int) -> Optional[str]:
@@ -450,3 +476,117 @@ def filenames_ending_in(suffix, root):
         if os.path.isdir(fullpath):
             filenames.extend(filenames_ending_in(suffix, fullpath))
     return filenames
+
+
+def add_check_overrides(checkids, profile_tag, overrides):
+    '''
+    Overridden checkids have a suffix identifying the specific
+    profile that customize their behaviour.
+
+    This helper function adds them to the list of checks and
+    ensures the original check is not redundantly listed.
+    '''
+
+    # First we add the overridden check ids:
+    checkids += [f'{checkid}:{profile_tag}'
+                 for checkid in overrides]
+
+    # But then we also remove the original check ids that
+    # may have also been included from the original profile:
+    checkids[:] = [checkid for checkid in checkids
+                   if checkid not in overrides]
+    return checkids
+
+
+def can_shape(ttFont, text, parameters=None):
+    '''
+    Returns true if the font can render a text string without any
+    .notdef characters.
+    '''
+    filename = ttFont.reader.file.name
+    vharfbuzz = Vharfbuzz(filename)
+    buf = vharfbuzz.shape(text, parameters)
+    return all(g.codepoint != 0 for g in buf.glyph_infos)
+
+
+def all_kerning(ttFont):
+    if "GPOS" not in ttFont:
+        return []
+    rules = []
+
+    def _invertClassDef(a, font):
+        classes = {}
+        for glyph, klass in a.items():
+            if klass not in classes:
+                classes[klass] = []
+            classes[klass].append(glyph)
+        glyphset = set(font.getGlyphOrder())
+        classes[0] = glyphset - set(a.keys())
+        return classes
+
+    kern_subtables = []
+    for lu in ttFont["GPOS"].table.LookupList.Lookup:
+        for subtable in lu.SubTable:
+            if subtable.LookupType == 9:
+                subtable = subtable.ExtSubTable
+            if subtable.LookupType == 2:
+                kern_subtables.append(subtable)
+
+    for subtable in kern_subtables:
+        if subtable.Format == 1:
+            for g, pair in zip(subtable.Coverage.glyphs, subtable.PairSet):
+                for vr in pair.PairValueRecord:
+                    rules.append((g, vr.SecondGlyph, vr.Value1, vr.Value2))
+        else:
+            class1 = _invertClassDef(subtable.ClassDef1.classDefs, ttFont)
+            class2 = _invertClassDef(subtable.ClassDef2.classDefs, ttFont)
+            for ix1, c1 in enumerate(subtable.Class1Record):
+                if ix1 not in class1:
+                    continue
+                for ix2, c2 in enumerate(c1.Class2Record):
+                    if ix2 not in class2:
+                        continue
+                    firstClass = list(
+                        set(class1[ix1]) & set(subtable.Coverage.glyphs)
+                    )
+                    for left in firstClass:
+                        for right in class2[ix2]:
+                            rules.append((left, right, c2.Value1, c2.Value2))
+    return rules
+
+
+def is_complex_shaper_font(ttFont):
+    for table in ["GSUB", "GPOS"]:
+        if table not in ttFont:
+            continue
+        if not ttFont[table].table.ScriptList:
+            continue
+        for rec in ttFont[table].table.ScriptList.ScriptRecord:
+            script = ot_tag_to_script(rec.ScriptTag)
+            if script in USE_SCRIPTS or script in INDIC_SCRIPTS:
+                return True
+            if script in ["Khmr", "Mymr", "Hang"]:
+                return True
+    return False
+
+
+def iterate_lookup_list_with_extensions(ttFont, table, callback, *args):
+    """Iterates over the lookup list of a font's GSUB/GPOS table, calling
+    the callback with the lookup and the provided arguments, but descending
+    into Extension subtables."""
+    if table not in ttFont or not ttFont[table].table.LookupList:
+        return
+
+    extension_type = 9 if table == "GPOS" else 7
+
+    for lookup in ttFont[table].table.LookupList.Lookup:
+        if lookup.LookupType == extension_type:
+            for xt in lookup.SubTable:
+                xt.SubTable = [xt.ExtSubTable]
+                xt.LookupType = xt.ExtSubTable.LookupType
+                callback(xt, *args)
+        else:
+            callback(lookup, *args)
+
+
+
