@@ -1,4 +1,5 @@
 import os
+from types import SimpleNamespace
 
 import fontTools.ttLib
 from fontTools.ttLib import TTFont
@@ -93,11 +94,11 @@ def test_check_monospace():
     # restore good value:
     ttFont["post"].isFixedPitch = IsFixedWidth.NOT_MONOSPACED
 
-    # Now we mark it as monospaced on the OS/2 and it should also fail:
+    # Now we mark it as monospaced on the OS/2 table and it should also fail:
     original_proportion = ttFont["OS/2"].panose.bProportion
     ttFont["OS/2"].panose.bProportion = PANOSE_Proportion.MONOSPACED
     assert_results_contain(check(ttFont),
-                           FAIL, 'bad-panose-proportion',
+                           FAIL, 'bad-panose',
                            'with a non-monospaced font with bad'
                            ' OS/2.panose.bProportion value (MONOSPACED) ...')
 
@@ -158,7 +159,7 @@ def test_check_monospace():
         ttFont["OS/2"].panose.bProportion = bad_value
         # again, we search the expected FAIL because we may algo get an outliers WARN here:
         assert_results_contain(check(ttFont),
-                               FAIL, 'mono-bad-panose-proportion',
+                               FAIL, 'mono-bad-panose',
                                f'Test FAIL with a monospaced font with bad'
                                f' OS/2.panose.bProportion value ({bad_value}) ...')
 
@@ -235,7 +236,9 @@ def assert_name_table_check_result(ttFont, index, name, check, value, expected_r
 
 def test_check_family_naming_recommendations():
     """ Font follows the family naming recommendations ? """
-    from fontbakery.profiles.name import com_google_fonts_check_family_naming_recommendations as check
+    check = CheckTester(opentype_profile,
+                        "com.google.fonts/check/family_naming_recommendations")
+
     # Our reference Mada Medium is known to be good
     ttFont = TTFont(TEST_FILE("mada/Mada-Medium.ttf"))
 
@@ -317,7 +320,8 @@ def test_check_family_naming_recommendations():
 
 
 def test_check_name_postscript_vs_cff():
-    from fontbakery.profiles.name import com_adobe_fonts_check_name_postscript_vs_cff as check
+    check = CheckTester(opentype_profile,
+                        "com.adobe.fonts/check/name/postscript_vs_cff")
     test_font = TTFont()
     test_font['CFF '] = fontTools.ttLib.newTable('CFF ')
     test_font['CFF '].cff.fontNames = ['SomeFontName']
@@ -330,6 +334,8 @@ def test_check_name_postscript_vs_cff():
         WindowsEncodingID.UNICODE_BMP,
         WindowsLanguageID.ENGLISH_USA
     )
+
+    test_font.reader = SimpleNamespace(file=SimpleNamespace(name="whatever"))
     assert_results_contain(check(test_font),
                            FAIL, 'mismatch')
 
@@ -344,8 +350,8 @@ def test_check_name_postscript_vs_cff():
 
 
 def test_check_name_postscript_name_consistency():
-    from fontbakery.profiles.name import \
-        com_adobe_fonts_check_name_postscript_name_consistency as check
+    check = CheckTester(opentype_profile,
+                        "com.adobe.fonts/check/name/postscript_name_consistency")
 
     base_path = portable_path("data/test/source-sans-pro/TTF")
     font_path = os.path.join(base_path, 'SourceSansPro-Regular.ttf')
@@ -375,24 +381,24 @@ def test_check_name_postscript_name_consistency():
 
 
 def test_check_family_max_4_fonts_per_family_name():
-    from fontbakery.profiles.name import \
-        com_adobe_fonts_check_family_max_4_fonts_per_family_name as check
+    check = CheckTester(opentype_profile,
+                        "com.adobe.fonts/check/family/max_4_fonts_per_family_name")
 
     base_path = portable_path("data/test/source-sans-pro/OTF")
 
     font_names = [
         'SourceSansPro-Black.otf',
-        'SourceSansPro-BlackIt.otf',
+        'SourceSansPro-BlackItalic.otf',
         'SourceSansPro-Bold.otf',
-        'SourceSansPro-BoldIt.otf',
+        'SourceSansPro-BoldItalic.otf',
         'SourceSansPro-ExtraLight.otf',
-        'SourceSansPro-ExtraLightIt.otf',
-        'SourceSansPro-It.otf',
+        'SourceSansPro-ExtraLightItalic.otf',
+        'SourceSansPro-Italic.otf',
         'SourceSansPro-Light.otf',
-        'SourceSansPro-LightIt.otf',
+        'SourceSansPro-LightItalic.otf',
         'SourceSansPro-Regular.otf',
         'SourceSansPro-Semibold.otf',
-        'SourceSansPro-SemiboldIt.otf']
+        'SourceSansPro-SemiboldItalic.otf']
 
     font_paths = [os.path.join(base_path, n) for n in font_names]
 
