@@ -174,11 +174,8 @@ def test_check_fsselection_matches_macstyle():
 def test_check_family_bold_italic_unique_for_nameid1():
     """Check that OS/2.fsSelection bold/italic settings are unique within each
     Compatible Family group (i.e. group of up to 4 with same NameID1)"""
-    # FIXME: This should work:
-    # check = CheckTester(opentype_profile,
-    #                     "com.adobe.fonts/check/family/bold_italic_unique_for_nameid1")
-    from fontbakery.profiles.os2 import \
-      com_adobe_fonts_check_family_bold_italic_unique_for_nameid1 as check
+    check = CheckTester(opentype_profile,
+                        "com.adobe.fonts/check/family/bold_italic_unique_for_nameid1")
     from fontbakery.constants import FsSelection
 
     base_path = portable_path("data/test/source-sans-pro/OTF")
@@ -186,9 +183,8 @@ def test_check_family_bold_italic_unique_for_nameid1():
     # these fonts have the same NameID1
     font_names = ['SourceSansPro-Regular.otf',
                   'SourceSansPro-Bold.otf',
-                  'SourceSansPro-It.otf',
-                  'SourceSansPro-BoldIt.otf']
-
+                  'SourceSansPro-Italic.otf',
+                  'SourceSansPro-BoldItalic.otf']
     font_paths = [os.path.join(base_path, n) for n in font_names]
     ttFonts = [TTFont(x) for x in font_paths]
 
