@@ -285,33 +285,6 @@ def test_check_family_single_directory():
                            f'with multiple dirs: {multiple_dirs}')
 
 
-def test_check_ftxvalidator_is_available():
-    """ Is the command `ftxvalidator` (Apple Font Tool Suite) available? """
-    check = CheckTester(universal_profile,
-                        "com.google.fonts/check/ftxvalidator_is_available")
-
-    font = "foo.ttf"
-    message = assert_PASS(check(font, {'ftxvalidator_cmd': '/usr/local/bin/ftxvalidator'}))
-    assert "is available" in message
-
-    message = assert_results_contain(check(font, {'ftxvalidator_cmd': None}),
-                                     WARN, "ftxvalidator-available")
-    assert "Could not find" in message
-
-
-def NOT_IMPLEMENTED_test_check_ftxvalidator():
-    """ Checking with ftxvalidator. """
-    # check = CheckTester(universal_profile,
-    #                     "com.google.fonts/check/ftxvalidator")
-    # TODO: Implement-me!
-    #
-    # code-paths:
-    # - PASS, "ftxvalidator passed this file."
-    # - FAIL, "ftxvalidator outputs to stderr."
-    # - ERROR, "ftxvalidator returned an error code."
-    # - ERROR, "ftxvalidator is not available!"
-
-
 def test_check_ots():
     """ Checking with ots-sanitize. """
     check = CheckTester(universal_profile,
@@ -485,6 +458,10 @@ def test_check_whitespace_ink():
     test_font = TTFont(TEST_FILE("nunito/Nunito-Regular.ttf"))
     assert_PASS(check(test_font))
 
+    test_font["cmap"].tables[0].cmap[0x1680] = "a"
+    assert_PASS(check(test_font),
+                'because Ogham space mark does have ink.')
+
     test_font["cmap"].tables[0].cmap[0x0020] = "uni1E17"
     assert_results_contain(check(test_font),
                            FAIL, 'has-ink',
@@ -514,9 +491,8 @@ def test_check_required_tables():
     optional_tables = ["cvt ", "fpgm", "loca", "prep",
                        "VORG", "EBDT", "EBLC", "EBSC",
                        "BASE", "GPOS", "GSUB", "JSTF",
-                       "DSIG", "gasp", "hdmx", "kern",
-                       "LTSH", "PCLT", "VDMX", "vhea",
-                       "vmtx"]
+                       "gasp", "hdmx", "kern", "LTSH",
+                       "PCLT", "VDMX", "vhea", "vmtx"]
     # Our reference Mada Regular font is good here
     ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
 
@@ -564,7 +540,7 @@ def test_check_required_tables():
         # and ensure that the second to last logged message is an
         # INFO status informing the user about it:
         assert_results_contain(check(ttFont),
-                               INFO, "required-tables",
+                               INFO, "optional-tables",
                                f'with optional table {required} ...')
         # remove the one we've just inserted before trying the next one:
         del ttFont.reader.tables[optional]
@@ -584,7 +560,6 @@ def test_check_unwanted_tables():
         "TSI3",
         "TSI5",
         "prop", # FIXME: Why is this one unwanted?
-        "MVAR", # Bugs in DirectWrite
     ]
     # Our reference Mada Regular font is good here:
     ttFont = TTFont(TEST_FILE("mada/Mada-Regular.ttf"))
@@ -721,26 +696,17 @@ def test_check_family_vertical_metrics(montserrat_ttFonts):
 
 
 def test_check_superfamily_vertical_metrics(montserrat_ttFonts, cabin_ttFonts, cabin_condensed_ttFonts):
-    from fontbakery.profiles.universal import com_google_fonts_check_superfamily_vertical_metrics as check
+    check = CheckTester(universal_profile,
+                        "com.google.fonts/check/superfamily/vertical_metrics")
 
-    assert_PASS(check([cabin_ttFonts,
-                       cabin_condensed_ttFonts]),
+    assert_PASS(check([], {"superfamily_ttFonts": [cabin_ttFonts,
+                                                   cabin_condensed_ttFonts]}),
                 'with multiple good families...')
 
-    assert_results_contain(check([cabin_ttFonts,
-                                  montserrat_ttFonts]),
+    assert_results_contain(check([], {"superfamily_ttFonts": [cabin_ttFonts,
+                                                              montserrat_ttFonts]}),
                            WARN, "superfamily-vertical-metrics",
                            'with families that diverge on vertical metric values...')
-    # FIXME:
-    # check = CheckTester(universal_profile,
-    #                     "com.google.fonts/check/superfamily/vertical_metrics")
-    #
-    # assert_PASS(check(cabin_ttFonts + cabin_condensed_ttFonts),
-    #             'with multiple good families...')
-    #
-    # assert_results_contain(check(cabin_ttFonts + montserrat_ttFonts),
-    #                        WARN, None, # FIXME: This needs a message keyword
-    #                        'with families that diverge on vertical metric values...')
 
 
 def test_check_STAT_strings():
@@ -788,3 +754,190 @@ def test_check_rupee():
                            FAIL, "missing-rupee",
                            "with a sample font missing it.")
 
+
+def test_check_unreachable_glyphs():
+    """Check font contains no unreachable glyphs."""
+    check = CheckTester(universal_profile,
+                        "com.google.fonts/check/unreachable_glyphs")
+
+    font = TEST_FILE("noto_sans_tamil_supplement/NotoSansTamilSupplement-Regular.ttf")
+    assert_PASS(check(font))
+
+    font = TEST_FILE("merriweather/Merriweather-Regular.ttf")
+    message = assert_results_contain(check(font), WARN, "unreachable-glyphs")
+    for glyph in [
+        "Gtilde",
+        "eight.dnom",
+        "four.dnom",
+        "three.dnom",
+        "two.dnom",
+        "i.dot",
+        "five.numr",
+        "seven.numr",
+        "bullet.cap",
+        "periodcentered.cap",
+        "ampersand.sc",
+        "I.uc",
+    ]:
+        assert glyph in message
+
+    for glyph in [
+        "caronvertical",
+        "acute.cap",
+        "breve.cap",
+        "caron.cap",
+        "circumflex.cap",
+        "dotaccent.cap",
+        "dieresis.cap",
+        "grave.cap",
+        "hungarumlaut.cap",
+        "macron.cap",
+        "ring.cap",
+        "tilde.cap",
+        "breve.r",
+        "breve.rcap",
+    ]:
+        assert glyph not in message
+
+
+def test_check_contour_count(montserrat_ttFonts):
+    """Check glyphs contain the recommended contour count"""
+    check = CheckTester(universal_profile,
+                        "com.google.fonts/check/contour_count")
+    # TODO: FAIL, "lacks-cmap"
+
+    for ttFont in montserrat_ttFonts:
+        # Montserrat which was used to assemble the glyph data,
+        # so, it should be good, except for that softhyphen...
+        # TODO: how can we test PASS then?
+        assert_results_contain(check(ttFont),
+                               WARN, 'softhyphen')
+
+    # Lets swap the glyf 'a' (2 contours) with glyf 'c' (1 contour)
+    for ttFont in montserrat_ttFonts:
+        ttFont['glyf']['a'] = ttFont['glyf']['c']
+        assert_results_contain(check(ttFont),
+                               WARN, 'contour-count')
+
+
+def test_check_cjk_chws_feature():
+    """Does the font contain chws and vchw features?"""
+    check = CheckTester(universal_profile,
+                        "com.google.fonts/check/cjk_chws_feature")
+
+    cjk_font = TEST_FILE("cjk/SourceHanSans-Regular.otf")
+    ttFont = TTFont(cjk_font)
+    assert_results_contain(check(ttFont),
+                           FAIL, "missing-chws-feature",
+                           'for Source Han Sans')
+
+    assert_results_contain(check(ttFont),
+                           FAIL, "missing-vchw-feature",
+                           'for Source Han Sans')
+
+    # Insert them.
+    from fontTools.ttLib.tables.otTables import FeatureRecord
+    chws = FeatureRecord()
+    chws.FeatureTag = "chws"
+    vchw = FeatureRecord()
+    vchw.FeatureTag = "vchw"
+    ttFont["GPOS"].table.FeatureList.FeatureRecord.extend([chws, vchw])
+
+    assert_PASS(check(ttFont))
+
+
+def test_check_designspace_has_sources():
+    """See if we can actually load the source files."""
+    check = CheckTester(universal_profile,
+                        "com.google.fonts/check/designspace_has_sources")
+
+    designspace = TEST_FILE("stupidfont/Stupid Font.designspace")
+    assert_PASS(check(designspace))
+
+    # TODO: FAIL, 'no-sources'
+
+
+def test_check_designspace_has_default_master():
+    """Ensure a default master is defined."""
+    check = CheckTester(universal_profile,
+                        "com.google.fonts/check/designspace_has_default_master")
+
+    designspace = TEST_FILE("stupidfont/Stupid Font.designspace")
+    assert_PASS(check(designspace))
+
+    # TODO: FAIL, 'not-found'
+
+
+def test_check_designspace_has_consistent_glyphset():
+    """Check consistency of glyphset in a designspace file."""
+    check = CheckTester(universal_profile,
+                        "com.google.fonts/check/designspace_has_consistent_glyphset")
+
+    designspace = TEST_FILE("stupidfont/Stupid Font.designspace")
+    assert_results_contain(check(designspace),
+                           FAIL, 'inconsistent-glyphset')
+
+    # TODO: Fix it and ensure it passes the check
+
+
+def test_check_designspace_has_consistent_codepoints():
+    """Check codepoints consistency in a designspace file."""
+    check = CheckTester(universal_profile,
+                        "com.google.fonts/check/designspace_has_consistent_codepoints")
+
+    designspace = TEST_FILE("stupidfont/Stupid Font.designspace")
+    assert_results_contain(check(designspace),
+                           FAIL, 'inconsistent-codepoints')
+
+    # TODO: Fix it and ensure it passes the check
+
+
+def test_check_transformed_components():
+    """Ensure component transforms do not perform scaling or rotation."""
+    check = CheckTester(universal_profile,
+                        "com.google.fonts/check/transformed_components")
+
+    font = TEST_FILE("cabin/Cabin-Regular.ttf")
+    assert_PASS(check(font),
+                "with a good font...")
+
+    # DM Sans v1.100 had some transformed components
+    font = TEST_FILE("dm-sans-v1.100/DMSans-Regular.ttf")
+    assert_results_contain(check(font),
+                           FAIL, 'transformed-components')
+
+
+def test_check_dotted_circle():
+    """Ensure dotted circle glyph is present and can attach marks."""
+    check = CheckTester(universal_profile,
+                        "com.google.fonts/check/dotted_circle")
+
+    font = TEST_FILE("mada/Mada-Regular.ttf")
+    assert_PASS(check(font),
+                "with a good font...")
+
+    font = TEST_FILE("cabin/Cabin-Regular.ttf")
+    assert_results_contain(check(font),
+                           WARN, "missing-dotted-circle")
+
+    font = TEST_FILE("broken_markazitext/MarkaziText-VF.ttf")
+    assert_results_contain(check(font),
+                           FAIL, "unattached-dotted-circle-marks")
+
+
+def test_check_gsub5_gpos7():
+    """Check if font contains any GSUB 5 or GPOS 7 lookups
+    which are not widely supported."""
+    check = CheckTester(universal_profile,
+                        "com.google.fonts/check/gsub5_gpos7")
+
+    font = TEST_FILE("mada/Mada-Regular.ttf")
+    assert_PASS(check(font),
+                "with a good font...")
+
+    font = TEST_FILE("notosanskhudawadi/NotoSansKhudawadi-Regular.ttf")
+    assert_results_contain(check(font),
+                           FAIL, "has-gsub5")
+
+    assert_results_contain(check(font),
+                           FAIL, "has-gpos7")
